// Snippet name: MollioSecondaryMenu
// Snippet description: Outputs the Secondary Menu for Mollio templates
// Revision: 1.0 ships with Etomite 0.6.1-Final
// Author: Lloyd Borrett - 2006-04-09
//
// Based on elements from the ListSiteMap and ListMenu snippets
// by jaredc@honeydewdesign.com
//
// This snippet was designed to show a nested
// list menu with each pagetitle being a
// link to that page. It will not include
// unpublished folders/pages OR its children,
// even if the children ARE published.
// List items are marked with CSS class values of
// active, last or first as appropriate.

// Configuration
   // $titleOfLinks [ string ]
   // What database field do you want the title of your links to be?
   // it can be any of the following:
   // id, pagetitle, description, parent, alias, longtitle.
   // If the field you choose is empty for any given document,
   // the the pagetitle of the document is used. 
   $titleOfLinks = 'longtitle';
   
   // $maxLevels [ int ]
   // Maximum number of levels to include. The default 4 is the number
   // of levels supported by the CSS styles.
   // A value of 0 will allow all levels.
   // Also settable with snippet variable MMM_levels:
   // [[MollioSecondaryMenu?MSM_levels=2]]
   $maxLevels = 4;
   

// ###########################################
// End config, the rest takes care of itself #
// ###########################################

// Initialize
$maxLevels = (isset($MSM_levels))? $MSM_levels : $maxLevels ;

// Overcome single use limitation on functions
global $MakeSecMenuDefined;

if(!isset($MakeSecMenuDefined)){
  function MakeSecMenu($funcEtomite, $listParent, $listLevel, $titleOfLinks, $maxLevels, $fullGeneology){
    $children = $funcEtomite->getActiveChildren($listParent, 'menuindex', 'ASC', 'id, pagetitle, parent, alias, longtitle, published');
    $childrenCount = count($children); 
    $ie = "\n";
    $pad = str_pad($pad,($listLevel * 2)," ");

    // start this level
    if ($listLevel == 0) {
      $output .= $pad.'<ul id="nav-secondary">'.$ie;
    } else {
      $output .= $ie.$pad.'<ul>'.$ie;
    }

    for($x=0; $x<$childrenCount; $x++) {
      $child = $children[$x];

      // Is this the current document or an ancestor?
      $ancestor = in_array($child['id'], $fullGeneology);

      // Set the class to active, last, first or none
      if ($ancestor) {
        $cssStyle = ' class="active"';
      } else {
	if (($x+1) == $childrenCount) {
          $cssStyle = ' class="last"';
        } else {
          if ($x == 0) {
            $cssStyle = ' class="first"';
          } else {
            $cssStyle = '';
          }
        }
      }

      $output .= $pad.'<li'.$cssStyle.'>';
      $output .= '<a href="[~'.$child['id'].'~]" title="';
      if ($child[$titleOfLinks] != "") {
        $output .= str_replace('"',"'",$child[$titleOfLinks]);
      } else {
        $output .= str_replace('"',"'",$child['pagetitle']);
      }
      $output .= '">'.$child['pagetitle'].'</a>';

      // Does this document have children?
      $hasChildren = $funcEtomite->getActiveChildren($child['id']);

      if ($hasChildren && $ancestor && (($maxLevels==0) || ($maxLevels > $listLevel+1 ))){
        $output .= MakeSecMenu($funcEtomite, $child['id'], $listLevel+1, $titleOfLinks, $maxLevels, $fullGeneology);
      }
      $output .= '</li>'.$ie;
    }
    $output .= $pad.'</ul>'.$ie;
    return $output;
  }
  $MakeSecMenuDefined = true;
}

$id = $etomite->documentIdentifier; //current document

// If we're at home, do nothing
$atHome = ($id == $etomite->config['site_start'])? true : false ;
if ($atHome) {
	return "";
}

// Create Geneology
$fullGeneology = array();
$geneologyMarker = $id;
while (($currentMarker = $etomite->getPageInfo($geneologyMarker, null, 'id,parent')) && ($currentMarker['parent'] != 0 ) ) {
    $fullGeneology[] = $currentMarker['id'];
    $geneologyMarker = $currentMarker['parent'];
}
$fullGeneology[] = 0;

return MakeSecMenu($etomite, $geneologyMarker, 0,  $titleOfLinks, $maxLevels, $fullGeneology);